@@ -1,4 +1,4 @@
-rwhatbufCat2<-function(rast, sites,bufsizes,att=1){
+rwhatbufCat2<-function(rast, sites,bufsizes,att=1,asList=FALSE){
 	require(splancs)
 	require(pgirmess)
 	require(rgdal)
@@ -26,6 +26,28 @@ rwhatbufCat2<-function(rast, sites,bufsizes,att=1){
 				res.list[[i]][[j]]<-table(minirast@data[,att][idx],useNA="ifany")
 			}
 		}
+		
+if (!asList) {
+	cat("Building data.frame...\n")
+	res2<-rep(list(NA),length(res.list))
+	for(i in 1:length(res.list)) {
+	res2[[i]]<-unlist(sapply(res.list[[i]],names))
+	}
+	res2<-sort(unique(unlist(res2)))
+	mymat<-matrix(0,ncol=length(res2),nrow=length(bufsizes)*nrow(coords))
+	colnames(mymat)<-res2
+	compteur<-0
+	for(i in 1:length(res.list)) {
+		for (j in 1:nrow(coords)) {
+			compteur<-compteur+1
+			idx<-match(names(res.list[[i]][[j]]),colnames(mymat))
+			mymat[compteur,idx]<-res.list[[i]][[j]]
+		}
+	}
+	rep(bufsizes,each=nrow(coords))
+  res.list<-data.frame(buffer=rep(bufsizes,each=nrow(coords)),ID=rep(1:nrow(coords),length(bufsizes)),mymat,check.names=FALSE)
+}		
+		
 cat("Finished !\n")
 return(res.list)
 }
